==> otyacraftengine-forge-2.1-build2-sources.jar: dev/felnull/otyacraftengine/client/renderer/blockentity/TestRenderer.java <==
package dev.felnull.otyacraftengine.client.renderer.blockentity;

import com.mojang.blaze3d.vertex.PoseStack;
import dev.architectury.registry.client.rendering.BlockEntityRendererRegistry;
import dev.felnull.otyacraftengine.OtyacraftEngine;
import dev.felnull.otyacraftengine.blockentity.TestBlockEntity;
import dev.felnull.otyacraftengine.client.model.SpecialModelLoader;
import dev.felnull.otyacraftengine.client.util.OERenderUtil;
import net.minecraft.client.Minecraft;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.Sheets;
import net.minecraft.client.renderer.blockentity.BlockEntityRendererProvider;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.util.Mth;
import net.minecraft.world.level.block.Blocks;
import var;

public class TestRenderer extends AbstractBlockEntityRenderer<TestBlockEntity> {

    public TestRenderer(BlockEntityRendererProvider.Context context) {
        super(context);
    }

    @Override
    public void render(TestBlockEntity blockEntity, float f, PoseStack poseStack, MultiBufferSource multiBufferSource, int i, int j) {
        // OERenderUtil.renderTextSprite(poseStack, multiBufferSource, new TextComponent("TEST"), 0, 0, 0, 1f, 0, 0, 0xFF0000FF, i);
        //     Minecraft.getInstance().getItemRenderer().renderStatic(new ItemStack(Items.APPLE), ItemTransforms.TransformType.FIXED, i, j, poseStack, multiBufferSource, 0);
        //      var vc = multiBufferSource.getBuffer(RenderType.lines());
        //      LevelRenderer.renderVoxelShape(poseStack, vc, Blocks.ANVIL.defaultBlockState().getShape(blockEntity.getLevel(), blockEntity.getBlockPos()), 0, 0, 0, 0, 0, 0, 0);
        var model = SpecialModelLoader.getInstance().getModel(new ResourceLocation(OtyacraftEngine.MODID, "block/test_model"));//OERenderUtil.getBlockModel(Blocks.STONE.defaultBlockState());
        var vc = multiBufferSource.m_6299_(Sheets.m_110790_());
        poseStack.m_85836_();
        float rot = Mth.m_14179_(f, blockEntity.getOldRoted(), blockEntity.getRoted());

        if (Minecraft.m_91087_().f_91073_.m_8055_(blockEntity.m_58899_().m_7495_()).m_60734_() == Blocks.f_50322_) {
            rot = blockEntity.getRoted();
        } else if (Minecraft.m_91087_().f_91073_.m_8055_(blockEntity.m_58899_().m_7495_()).m_60734_() == Blocks.f_50090_) {
            rot = Mth.m_14179_(f, blockEntity.getRoted() - 3, blockEntity.getRoted());
        }
        poseStack.m_85837_(0.5f, 0.5f, 0.5f);
        OERenderUtil.poseRotateX(poseStack, rot);
        OERenderUtil.poseRotateY(poseStack, rot);
        OERenderUtil.poseRotateZ(poseStack, rot);

        poseStack.m_85837_(-0.5f, -0.5f, -0.5f);
        OERenderUtil.renderModel(poseStack, vc, model, i, j);
        poseStack.m_85849_();
    }

    public static void init() {
        BlockEntityRendererRegistry.register(TestBlockEntity.TEST_BLOCKENTITY, TestRenderer::new);
    }
}

==> otyacraftengine-forge-2.2-build2-sources.jar: dev/felnull/otyacraftengine/client/renderer/blockentity/TestRenderer.java <==
package dev.felnull.otyacraftengine.client.renderer.blockentity;

import com.mojang.blaze3d.vertex.PoseStack;
import dev.architectury.registry.client.rendering.BlockEntityRendererRegistry;
import dev.felnull.otyacraftengine.OtyacraftEngine;
import dev.felnull.otyacraftengine.blockentity.TestBlockEntity;
import dev.felnull.otyacraftengine.client.util.OEModelUtil;
import dev.felnull.otyacraftengine.client.util.OERenderUtil;
import net.minecraft.client.Minecraft;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.Sheets;
import net.minecraft.client.renderer.blockentity.BlockEntityRendererProvider;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.util.Mth;
import net.minecraft.world.level.block.Blocks;
import var;

public class TestRenderer extends AbstractBlockEntityRenderer<TestBlockEntity> {

    public TestRenderer(BlockEntityRendererProvider.Context context) {
        super(context);
    }

    @Override
    public void render(TestBlockEntity blockEntity, float f, PoseStack poseStack, MultiBufferSource multiBufferSource, int i, int j) {
        // OERenderUtil.renderTextSprite(poseStack, multiBufferSource, new TextComponent("TEST"), 0, 0, 0, 1f, 0, 0, 0xFF0000FF, i);
        //     Minecraft.getInstance().getItemRenderer().renderStatic(new ItemStack(Items.APPLE), ItemTransforms.TransformType.FIXED, i, j, poseStack, multiBufferSource, 0);
        //      var vc = multiBufferSource.getBuffer(RenderType.lines());
        //      LevelRenderer.renderVoxelShape(poseStack, vc, Blocks.ANVIL.defaultBlockState().getShape(blockEntity.getLevel(), blockEntity.getBlockPos()), 0, 0, 0, 0, 0, 0, 0);
        var model = OEModelUtil.getModel(new ResourceLocation(OtyacraftEngine.MODID, "block/test_model"));//OERenderUtil.getBlockModel(Blocks.STONE.defaultBlockState());
        var vc = multiBufferSource.m_6299_(Sheets.m_110790_());
        poseStack.m_85836_();
        float rot = Mth.m_14179_(f, blockEntity.getOldRoted(), blockEntity.getRoted());

        if (Minecraft.m_91087_().f_91073_.m_8055_(blockEntity.m_58899_().m_7495_()).m_60734_() == Blocks.f_50322_) {
            rot = blockEntity.getRoted();
        } else if (Minecraft.m_91087_().f_91073_.m_8055_(blockEntity.m_58899_().m_7495_()).m_60734_() == Blocks.f_50090_) {
            rot = Mth.m_14179_(f, blockEntity.getRoted() - 3, blockEntity.getRoted());
        }
        poseStack.m_85837_(0.5f, 0.5f, 0.5f);
        OERenderUtil.poseRotateX(poseStack, rot);
        OERenderUtil.poseRotateY(poseStack, rot);
        OERenderUtil.poseRotateZ(poseStack, rot);

        poseStack.m_85837_(-0.5f, -0.5f, -0.5f);
        OERenderUtil.renderModel(poseStack, vc, model, i, j);
        poseStack.m_85849_();
    }

    public static void init() {
        BlockEntityRendererRegistry.register(TestBlockEntity.TEST_BLOCKENTITY, TestRenderer::new);
    }
}
